@@ -411,7 +411,11 @@ class BaseSchema(AutoSchema):
         return custom_response
 
     def map_field(self, field):
-
+        """
+            This function was obtained from the django rest framework and
+            the only part changed was the addition of the if clause for
+            the serializers.JSONField
+        """
         # Nested Serializers, `many` or not.
         if isinstance(field, serializers.ListSerializer):
             return {
