@@ -58,3 +58,14 @@ class IsCustomUserPermission(permissions.BasePermission):
             except (KeyError, TypeError):
                 return False
         return False
+
+
+class IsLoggedInAndNurse(permissions.BasePermission):
+    def has_permission(self, request, view):
+        kwargs = request.parser_context['kwargs']
+        user_id = get_user_id(kwargs)
+
+        return request.user and 'user_id' in request.user \
+            and user_id == request.user['user_id']\
+            and 'role' in request.user \
+            and 'nurse' == request.user['role']
